import axios from 'axios'
import { ElMessage, ElMessageBox } from 'element-plus'

const request = axios.create({
  baseURL: import.meta.env.VITE_BASE_API,
})

// 异常拦截处理器
const errorHandler = (error: any) => {
  const status = error.response.status
  const data = error.response.data

  if (status === 400) {
    ElMessage.error(data.msg)
  } else if (status === 403) {
    ElMessage.error('无权限访问')
  } else if (status === 404) {
    ElMessage.error('接口不存在')
  } else if (status === 500) {
    ElMessage.error('服务器错误')
  }

  return Promise.reject(error.response)
}

request.interceptors.response.use((res) => {
  const data = res.data
  if (data.success || data.code === 200) {
    return data
  } else {
    ElMessage.error(data.msg)
    return Promise.reject(data)
  }
}, errorHandler)

export default request
